/* $Id: recipe_main.c,v 1.3 2007/08/09 08:16:04 lbilbao Exp $
 *
 * This file is part of the VISIR Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: lbilbao $
 * $Date: 2007/08/09 08:16:04 $
 * $Revision: 1.3 $
 * $Name: HEAD $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*-----------------------------------------------------------------------------
                                Includes
 -----------------------------------------------------------------------------*/

#include <assert.h>

#include <cpl.h>

#include "irplib_plugin.h"


/*----------------------------------------------------------------------------*/
/**
 * @defgroup recipe_main   General plugin tests
 */
/*----------------------------------------------------------------------------*/

/**@{*/

/*-----------------------------------------------------------------------------
                            Function definitions
 -----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/**
  @brief    Find a plugin and submit it to some tests
  @return   0 iff succesful

 */
/*----------------------------------------------------------------------------*/
int main(void)
{

    const char * tags[] = {
        "ERROR_TAG",
        "TECH_FOCUS",
        "TECH_FOCUS",
        "TECH_FOCUS",
        "TECH_FOCUS",
        "TECH_FOCUS",
        "CAL_DARK",
        "CAL_DARK",
        "CAL_DARK",
        "CAL_DARK",
        "CAL_DARK",
        "CAL_DETLIN_DARK",
        "CAL_DETLIN_DARK",
        "CAL_DETLIN_DARK",
        "CAL_DETLIN_DARK",
        "CAL_DETLIN_DARK",
        "IM_JITTER_OBJ",
        "IM_JITTER_OBJ",
        "IM_JITTER_OBJ",
        "IM_JITTER_OBJ",
        "IM_JITTER_OBJ",
        "CAL_FLAT_LAMP",
        "CAL_FLAT_LAMP",
        "CAL_FLAT_LAMP",
        "CAL_FLAT_LAMP",
        "CAL_FLAT_LAMP",
        "SLIT_IMG",
        "SLIT_IMG",
        "SLIT_IMG",
        "SLIT_IMG",
        "SLIT_IMG",
        "CAL_PSF",
        "CAL_PSF",
        "CAL_PSF",
        "CAL_PSF",
        "CAL_PSF",
        "CAL_FLAT_TW",
        "CAL_FLAT_TW",
        "CAL_FLAT_TW",
        "CAL_FLAT_TW",
        "CAL_FLAT_TW",
        "CAL_STD_JITTER",
        "CAL_STD_JITTER",
        "CAL_STD_JITTER",
        "CAL_STD_JITTER",
        "CAL_STD_JITTER",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ"
    };

    cpl_pluginlist * pluginlist;
    const size_t ntags = sizeof(tags) / sizeof(char*);
    int error;


#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 0, 0)
    cpl_init(CPL_INIT_DEFAULT);
#else
    cpl_init();
#endif

    pluginlist = cpl_pluginlist_new();

    error = cpl_plugin_get_info(pluginlist);

    assert( !error );

    error = irplib_plugin_test(pluginlist, ntags, tags);

    cpl_pluginlist_delete(pluginlist);

    if (!cpl_memory_is_empty()) {
        cpl_msg_error(cpl_func, "The plugin is leaking memory");
        cpl_memory_dump();
        if (!error) error = CPL_ERROR_UNSPECIFIED;
    }

    cpl_end();

    return error;

}

/**@}*/
